doapfiend.cli.DoapFiend

Package doapfiend :: Module cli :: Class DoapFiend |
[hide private]
[frames] | no frames]

# Class DoapFiend

source code

    object --+
             |
            DoapFiend

`DoapFiend` class

Instance Methods | [hide private]
__init__(self) Initialize attributes, set logger | source code
None |
by_homepage(self, url) Print DOAP given a project's homepage | source code
set_log_level(self) Set log level according to command-line options | source code
doapfiend_version(self) Print doapfiend version | source code
None |
by_pkg_index(self, index, project_name) Display DOAP for a package index project name index examples: sf - SourceForge, fm - Freshmeat | source code
None |
show_doap(self, url) Display DOAP given its URL | source code
None |
print_doap(self, doap_xml) Print doap in one of two serializations or plain text | source code
run(self) Run doapfiend command | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
Initialize attributes, set logger Overrides: object.__init__

### by_homepage(self, url) | source code
Print DOAP given a project's homepage Parameters: `url` (string) - URL of homepage of a project Returns: None Print a DOAP profile

### by_pkg_index(self, index, project_name) | source code
Display DOAP for a package index project name index examples: sf - SourceForge, fm - Freshmeat Parameters: `index` (string) - Package index two letter abbreviation `project_name` (string) - project name Returns: None Nothing, just prints DOAP

### show_doap(self, url) | source code
Display DOAP given its URL Parameters: `url` (string) - URL of DOAP profile in RDF/XML serialization Returns: None Just displays DOAP

### print_doap(self, doap_xml) | source code
Print doap in one of two serializations or plain text Parameters: `doap_xml` (text) - DOAP in RDF/XML serialization Returns: None Just displays DOAP